@@ -40,11 +40,6 @@
 #include <wx/listbox.h>
 #include <wx/clntdata.h>
 
-// wxLaunchDefaultBrowser backport
-#if !wxCHECK_VERSION(2, 6, 4) && __UNIX__
-#include <wx/mimetype.h>
-#endif
-
 #include "IOUtils.hpp"
 #include "InstallVerifyFrame.hpp"
 #include "Options.hpp"
@@ -58,6 +53,63 @@
 #define LOGO_WIDTH 160
 #define LOGO_HEIGHT 120
 
+/**
+ * Custom paint method to display the animation efficiently.
+ * Cf. doc/animation.txt for details.
+ */
+#define TIMER_ID 1  // arbitrary, maybe there's a better way
+#define FPS 50
+class DFAnimationPanel : public wxPanel
+{
+private:
+  double pos;
+  double dpos;
+  DFArcFrame* frame;
+public:
+  DFAnimationPanel(DFArcFrame* frame, wxWindow* parent) :
+    wxPanel(parent, wxID_ANY),
+    frame(frame),
+    pos(.0), dpos(.0)
+  { }
+
+  void setIndex(int idx)
+  {
+    dpos = (idx+1) * LOGO_HEIGHT;
+  }
+
+  void OnPaint(wxPaintEvent &)
+  {
+    wxPaintDC dst(this);
+    dst.DrawRectangle(pos, pos, 50, 70);
+    wxMemoryDC src(frame->mAllLogos);
+    dst.Blit(0, 0, LOGO_WIDTH, LOGO_HEIGHT, &src, 0, pos);
+  }
+
+  /**
+   * Update the animation parameters regularly.
+   */
+  void OnIdle(wxIdleEvent &)
+  {
+    if (abs(pos - dpos) < 10e-6)
+      // destination reached, using non-exact comparison because pos
+      // and dpos are of type double.
+      return;
+
+    // Simple easing
+    pos += (dpos - pos) / 7;
+
+    Refresh(/*eraseBackground=*/false);
+
+    wxMilliSleep(1000.0/FPS); // ms
+  }
+  DECLARE_EVENT_TABLE()
+};
+BEGIN_EVENT_TABLE(DFAnimationPanel, wxPanel)
+  EVT_PAINT(DFAnimationPanel::OnPaint)
+  EVT_IDLE(DFAnimationPanel::OnIdle)
+END_EVENT_TABLE()
+
+
 // FRAME EVENT TABLE
 BEGIN_EVENT_TABLE(DFArcFrame, wxFrame)
 EVT_SHOW(DFArcFrame::onShow)
@@ -90,19 +142,6 @@ EVT_CHECKBOX(ID_Debug, DFArcFrame::OnSetPlayOption)
 EVT_CHECKBOX(ID_V107, DFArcFrame::OnSetPlayOption)
 END_EVENT_TABLE()
 
-// Integer wrapper class to store the DMod index associated with a
-// listbox entry from mDModListBox. Previously I was abusing 'void*'
-// as 'int' but g++ produces an error under amd64.  If we were using
-// glib, we'd use GINT_TO_POINTER().  Sadly, we're not using glib :/
-// Using wxClientData as a base class to make the wxListBox
-// automatically free client data when needed.
-class Integer : public wxClientData
-{
- public:
-  int i;
-  Integer(int i) : i(i) {}
-};
-
 DFArcFrame::DFArcFrame() :
 DFArcFrame_Base(NULL, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxDEFAULT_FRAME_STYLE),
   mNoDmods(false),
@@ -140,7 +179,7 @@ void DFArcFrame::OnAbout(wxCommandEvent& aCommandEvent)
 void DFArcFrame::showDeveloperButtons(bool visible)
 {
   wxSizer *mButtonSizer = mEditButton->GetContainingSizer();
-  wxSizer *mImageSizer = mLogoButton->GetContainingSizer();
+  wxSizer *mImageSizer = mAnimationPanel->GetContainingSizer();
   mImageSizer->Show(mButtonSizer, visible);
   // Re-layout, starting with expanding mDModListBox
   mDModListBox->GetContainingSizer()->Layout();
@@ -154,12 +193,13 @@ static wxBitmap CreateTextLogo(wxString text)
   dc.SetBackground(*wxBLACK_BRUSH);
   dc.SetTextForeground(*wxWHITE);
   dc.Clear();
-  // position '?'
-  int w, h;
-  dc.GetTextExtent(text, &w, &h);
+  // Center text
+  // (There seem to be a bug in GetTextExtent in wx2.8.10, the
+  // calculated width is smaller than the drawned width)
+  wxSize size = dc.GetTextExtent(text);
   dc.DrawText(text,
-	      (LOGO_WIDTH - w) / 2,
-	      (LOGO_HEIGHT - h) / 2);
+	      (LOGO_WIDTH - size.GetWidth()) / 2,
+	      (LOGO_HEIGHT - size.GetHeight()) / 2);
   dc.SelectObject(wxNullBitmap);
   return lLogo;
 }
@@ -167,6 +207,15 @@ static wxBitmap CreateTextLogo(wxString text)
 // GUI for main screen (with no args).
 void DFArcFrame::PrepareGUI()
 {   
+  // Replace wxGlade's plain wxPanel with our custom class -
+  // cf. DFArcFrame_Base.cpp
+  wxSizer *sizer = mAnimationPanel->GetContainingSizer();
+  sizer->Detach(mAnimationPanel);
+  delete mAnimationPanel;
+  mAnimationPanel = new DFAnimationPanel(this, panel_1);
+  mAnimationPanel->SetMinSize(wxSize(160, 120));
+  sizer->Insert(1, mAnimationPanel, 0, wxLEFT|wxALIGN_BOTTOM|wxALIGN_CENTER_HORIZONTAL, 10);
+
   // Features not supported by wxGlade:
   SetIcon(wxIcon(dink_xpm));
   mSplitter->SetSashGravity(0.5); // proportional resize
@@ -195,14 +244,13 @@ void DFArcFrame::PrepareGUI()
      Choose!". This is included in the 160x120px logo box in the main
      window and it doesn't word-wrap. */
   mDefaultLogoBitmap = CreateTextLogo(_("< Pick a D-Mod"));
-  mLogoButton->SetBitmap(mDefaultLogoBitmap);
+  ((DFAnimationPanel*)mAnimationPanel)->setIndex(-1);
 }
 
 void DFArcFrame::updateDescription()
 {
   std::fstream lFileStream;
   wxString lDescription;
-  wxBitmap lLogoBitmap;
 
   // Set the current D-Mod directory to the currently selected item's client string
   DMod cur_dmod = mAvailableDModsList.at(mSelectedDModIndex);
@@ -210,29 +258,6 @@ void DFArcFrame::updateDescription()
   mConfig->Update();
   mDmodDescription->SetValue(cur_dmod.GetDescription());
   mStatusBar->SetStatusText(mConfig->mSelectedDmod);
-  
-  wxString lDmodPreview(mConfig->mSelectedDmod + _T("/preview.bmp"));
-  IOUtils::ciconvert(lDmodPreview);
-  wxString lDmodTitle(mConfig->mSelectedDmod + _T("/graphics/title-01.bmp"));
-  IOUtils::ciconvert(lDmodTitle);
-  if (::wxFileExists(lDmodPreview) == true)
-    {
-      lLogoBitmap = wxBitmap(lDmodPreview, wxBITMAP_TYPE_BMP);
-    }
-  else if (::wxFileExists(lDmodTitle) == true)
-    {
-      wxImage lImage(lDmodTitle);
-      lImage.Rescale(LOGO_WIDTH, LOGO_HEIGHT);
-      lLogoBitmap = wxBitmap(lImage);
-    }
-  else
-    {
-      lLogoBitmap = CreateTextLogo(cur_dmod.GetBaseName());
-    }
-  lLogoBitmap.SetWidth(LOGO_WIDTH);
-  lLogoBitmap.SetHeight(LOGO_HEIGHT);
-  mLogoButton->SetBitmap(lLogoBitmap);
-  return;
 }
 
 void DFArcFrame::SelectDModFromListBox()
@@ -248,7 +273,57 @@ void DFArcFrame::SelectDModFromListBox()
       mPlayButton->Enable();
       mEditButton->Enable();
       mPackageButton->Enable();
+
+      // Fill-in translations list
+      wxString cur_locale_name = mConfig->mForceLocale;
+      if (mConfig->mForceLocale == wxEmptyString) {
+	const wxLanguageInfo* li = wxLocale::GetLanguageInfo(wxLocale::GetSystemLanguage());
+	if (li != NULL)
+	  cur_locale_name = li->CanonicalName;
+      }
+
+      mGameLocaleList->Clear();
+      wxArrayString mo_files;
+      wxString mo_dir = mConfig->mSelectedDmod + wxFileName::GetPathSeparator() + wxT("l10n");
+      if (wxDir::Exists(mo_dir)) {
+	wxDir::GetAllFiles(mo_dir, &mo_files, wxT("*.mo"));
+	mo_files.Sort();
+	for (int i = 0; i < mo_files.Count(); i++)
+	  {
+	    // dmod/l10n/fr/LC_MESSAGES/dmod.mo
+	    wxFileName mo(mo_files.Item(i));
+	    mo.RemoveLastDir();
+	    wxArrayString dirs = mo.GetDirs();
+	    wxString dir = dirs.Item(dirs.Count()-1);
+	    wxString label = dir;
+	    wxString locale_name = dir;
+	    const wxLanguageInfo* li = wxLocale::FindLanguageInfo(locale_name);
+	    if (li != NULL) {
+	      label += wxT(" - ") + wxString(wxGetTranslation(li->Description));
+	      locale_name = li->CanonicalName;
+	    }
+	    mGameLocaleList->Append(label);
+	    mGameLocaleList->SetClientObject(i, new ClientDataString(locale_name));
+	    if (cur_locale_name == locale_name)
+	      mGameLocaleList->Select(i);
+	  }
+      }
+      if (mGameLocaleList->GetCount() == 0) {
+	mGameLocaleList->Append(_("No translations"));
+	mGameLocaleList->Select(0);
+	mGameLocaleList->Disable();
+      } else {
+	// Not displaying the default language explicitely, because it
+	// makes the user think that a translation is always available.
+	// mGameLocaleList->Insert(wxString(_("Default language")) + wxT(" (") + cur_locale_name + wxT(")"), 0);
+	mGameLocaleList->Insert(_("Don't translate"), 0);
+	mGameLocaleList->SetClientObject(0, new ClientDataString(wxT("C")));
+	mGameLocaleList->Enable();
+	if (mGameLocaleList->GetSelection() == wxNOT_FOUND)
+	  mGameLocaleList->Select(0);
+      }
     }
+  ((DFAnimationPanel*)mAnimationPanel)->setIndex(lb_index);
 }
 
 void DFArcFrame::OnEvtListBox(wxCommandEvent &Event)
@@ -367,57 +442,167 @@ wxString DFArcFrame::BuildCommand(enum program progname)
 void DFArcFrame::OnPlay(wxCommandEvent &Event)
 {
   wxString lCommand = BuildCommand(GAME);
+
+  // Configure locale
+  wxString save_LANGUAGE;
+  wxString save_LC_ALL;
+  wxString save_LC_MESSAGES;
+  wxString save_LC_CTYPE;
+  bool save_LANGUAGE_exists    = wxGetEnv(wxT("LANGUAGE"),    &save_LANGUAGE);
+  bool save_LC_ALL_exists      = wxGetEnv(wxT("LC_ALL"),      &save_LC_ALL);
+  bool save_LC_CTYPE_exists    = wxGetEnv(wxT("LC_CTYPE"),    &save_LC_CTYPE);
+  bool save_LC_MESSAGES_exists = wxGetEnv(wxT("LC_MESSAGES"), &save_LC_MESSAGES);
+
+  wxString locale_name = mConfig->mForceLocale;
+  int idx = mGameLocaleList->GetSelection();
+  if (idx != wxNOT_FOUND)
+    {
+      wxClientData* wcd = mGameLocaleList->GetClientObject(idx);
+      if (wcd != NULL)
+	locale_name = ((ClientDataString*)wcd)->s;
+    }
+  if (locale_name != wxEmptyString)
+    {
+      // locale_name is in the form 'xx_YY', e.g. 'da_DK'
+
+      // (gettext.info.gz)The LANGUAGE variable: LANGUAGE > LC_ALL > LC_* > LANG
+      wxUnsetEnv(wxT("LANGUAGE"));
+      wxUnsetEnv(wxT("LC_ALL"));
+
+      // Locales need to be precisely set, including the encoding,
+      // even if in the case of FreeDink, we don't need it.
+      // http://lists.gnu.org/archive/html/bug-gnu-utils/2010-10/msg00018.html
+#if defined _WIN32 || defined __WIN32__ || defined __CYGWIN__ || defined __EMX__ || defined __DJGPP__
+      // Under woe, things are pretty sloppy, no worry - except that
+      // you won't get any warning if you lack fonts or whatever is
+      // needed for your language.
+      wxSetEnv(wxT("LC_ALL"), locale_name);
+#else
+      // Look through $(locale -a) and check if there's a matching
+      // locale, otherwise explain to the user that he needs to
+      // install the locale.  Not sure if there's a similar method
+      // under woe to get the installed locales.
+      wxArrayString installed_locales;
+      long code = ::wxExecute(wxT("locale -a"), installed_locales, wxEXEC_SYNC);
+      if (code == 0) // good exit code
+	{
+	  bool found = false;
+	  if (!found)
+	    {
+	      for (int i = 0; i < installed_locales.Count(); i++)
+		{
+		  if (installed_locales.Item(i).StartsWith(locale_name))
+		    {
+		      found = true;
+		      locale_name = installed_locales.Item(i);
+		      wxSetEnv(wxT("LC_ALL"), locale_name);
+		      break;
+		    }
+		}
+	    }
+	  if (!found)
+	    {
+	      // Try with the language name  / without the country name
+	      wxString language_name = locale_name.Mid(0,2);
+	      for (int i = 0; i < installed_locales.Count(); i++)
+		{
+		  if (installed_locales.Item(i).StartsWith(language_name))
+		    {
+		      found = true;
+		      locale_name = installed_locales.Item(i);
+		      wxSetEnv(wxT("LC_ALL"), locale_name);
+		      break;
+		    }
+		}
+	    }
+	  if (!found)
+	    {
+	      // Poor-man's / fallback i18n:
+	      // - LC_CTYPE and LC_MESSAGES to en_US.UTF-8 (if available)
+	      // - LANGUAGE to the locale
+	      found = (installed_locales.Index(wxT("en_US.UTF-8"), false) != wxNOT_FOUND);
+	      if (!found)
+		found = (installed_locales.Index(wxT("en_US.utf8"), false) != wxNOT_FOUND);
+	      if (found)
+		{
+		  wxSetEnv(wxT("LC_CTYPE"), wxT("en_US.UTF-8"));
+		  wxSetEnv(wxT("LC_MESSAGES"), wxT("en_US.UTF-8"));
+		  wxSetEnv(wxT("LANGUAGE"), locale_name);
+		}
+	    }
+	  if (!found)
+	    ::wxMessageBox(wxString::Format(_("The '%s' locale is not installed on your computer"
+					      " (locales tells the computer how to manage a language)."
+					      " You need to install it - check your system documentation."),
+					    locale_name.c_str()), _("Warning"), wxICON_EXCLAMATION, this);
+	  // try anyway; this also prevent fallback-ing to the system language
+	  wxSetEnv(wxT("LC_ALL"), locale_name);
+	}
+#endif
+    }
   
+
   // Start the child process.
   long code = 0;
-  bool found = true;
-  if (mConfig->mCloseDfarcOnPlay)
-    {
-      // We want to run in asynchronous mode, so we can execute just
-      // after starting Dink. Unfortunately wxWidgets sucks big time
-      // when it comes to wxExecute's return values, apparently
-      // because it successfully starts a shell before actually
-      // starting the processus. This requires a work-around to detect
-      // Dink's presence:
-      if ((unsigned char)(code = ::wxExecute(mConfig->mDinkExe + _T(" --version"), wxEXEC_SYNC))
-	  == (unsigned char)-1) // 255 if not casted under GNU/Linux, always -1 under woe...
-	found = false;
+  bool found = false;
+  bool error = true;
 
-      if (found)
-	{
-	  if ((code = ::wxExecute(lCommand, wxEXEC_ASYNC)) < 0)
-	    ::wxMessageBox(wxString::Format(_("Dink Smallwood failed! Error code %d."),
-					    code),
-			   _("Error"));
-	  else
-	    this->Close(true);
-	}
+  if (
+#if defined _WIN32 || defined __WIN32__ || defined __CYGWIN__ || defined __EMX__ || defined __DJGPP__
+      (code = ::wxExecute(lCommand, wxEXEC_SYNC)) == -1
+#else
+      // (long)code == 255 if not found, but -1 if segfault, under GNU/Linux
+      (code = ::wxExecute(lCommand, wxEXEC_SYNC)) == 255
+#endif
+      )
+    {
+      // Dink executable was not found
+      error = false;
+      found = false;
+    }
+  else if (code != 0)
+    {
+      // Dink returned non-zero or experienced a segmentation fault
+      error = true;
+      found = true;
     }
   else
     {
-      // If not closing DFArc when playing just run Dink in
-      // synchronous mode, with actual^Wbetter error reporting
-      if ((unsigned char)(code = ::wxExecute(lCommand, wxEXEC_SYNC)) == (unsigned char)-1)
-	{
-	  found = false;
-	}
-      else if (code != 0)
-	{
-	  ::wxMessageBox(wxString::Format(_("Dink Smallwood failed! Error code %d."),
-					  code),
-			 _("Error"));
-	}
-      else
-	{
-	  // Dink ran fine.
-	}
+      // Dink ran fine
+      error = false;
+      found = true;
     }
 
+  if (error)
+      ::wxMessageBox(wxString::Format(_("Dink Smallwood failed! Error code %d."),
+				      code, wxICON_EXCLAMATION, this),
+		     _("Error"));
   if (!found)
     ::wxMessageBox(wxString::Format(_("Dink Smallwood ('%s') was not found on your computer."
 				      " Please configure the Dink program name in the Options menu."),
-				    mConfig->mDinkExe.c_str()),
+				    mConfig->mDinkExe.c_str(), wxICON_ERROR, this),
 		   _("Error"));
+
+  // Restore environment variables
+  if (save_LANGUAGE_exists)
+    wxSetEnv(wxT("LANGUAGE"), save_LANGUAGE);
+  else
+    wxUnsetEnv(wxT("LANGUAGE"));
+  if (save_LC_ALL_exists)
+    wxSetEnv(wxT("LC_ALL"), save_LC_ALL);
+  else
+    wxUnsetEnv(wxT("LC_ALL"));
+  if (save_LC_CTYPE_exists)
+    wxSetEnv(wxT("LC_CTYPE"), save_LC_CTYPE);
+  else
+    wxUnsetEnv(wxT("LC_CTYPE"));
+  if (save_LC_MESSAGES_exists)
+    wxSetEnv(wxT("LC_MESSAGES"), save_LC_MESSAGES);
+  else
+    wxUnsetEnv(wxT("LC_MESSAGES"));
+
+  if (mConfig->mCloseDfarcOnPlay && found && !error)
+    this->Close(true);
 }
 
 void DFArcFrame::onEdit( wxCommandEvent& aEvent )
@@ -428,7 +613,7 @@ void DFArcFrame::onEdit( wxCommandEvent& aEvent )
 			   " Altering maps can ruin the game."
 			   " Are you sure you want to continue?"),
 			 _("Warning"),
-			 wxOK | wxCANCEL | wxICON_INFORMATION, this ) == wxCANCEL)
+			 wxOK | wxCANCEL | wxICON_INFORMATION, this) == wxCANCEL)
         {
 	  return;
         }
@@ -446,7 +631,14 @@ void DFArcFrame::onEdit( wxCommandEvent& aEvent )
   // Start the child process.
   long code = 0;
 
-  if ((unsigned char)(code = ::wxExecute(lCommand, wxEXEC_SYNC)) == (unsigned char)-1)
+  if (
+#if defined _WIN32 || defined __WIN32__ || defined __CYGWIN__ || defined __EMX__ || defined __DJGPP__
+      (code = ::wxExecute(lCommand, wxEXEC_SYNC)) == -1
+#else
+      // (long)code == 255 if not found, but -1 if segfault, under GNU/Linux
+      (code = ::wxExecute(lCommand, wxEXEC_SYNC)) == 255
+#endif
+      )
     ::wxMessageBox(wxString::Format(_("The editor ('%s') was not found on your computer."
 				      " Please configure the editor program name in the Options menu."),
 				    mConfig->mEditorExe.c_str()),
@@ -463,17 +655,17 @@ void DFArcFrame::onRefresh( wxCommandEvent& aEvent )
 
 void DFArcFrame::onDownload( wxCommandEvent& aEvent )
 {
-  launchURL(_T("http://www.dinknetwork.com/"));
+  ::wxLaunchDefaultBrowser(_T("http://www.dinknetwork.com/"));
 }
 
 void DFArcFrame::onWalkthroughs( wxCommandEvent& aEvent )
 {
-  launchURL(_T("http://solutions.dinknetwork.com/"));
+  ::wxLaunchDefaultBrowser(_T("http://solutions.dinknetwork.com/"));
 }
 
 void DFArcFrame::onForums( wxCommandEvent& aEvent )
 {
-  launchURL(_T("http://www.dinknetwork.com/forum.cgi"));
+  ::wxLaunchDefaultBrowser(_T("http://www.dinknetwork.com/forum.cgi"));
 }
 
 void DFArcFrame::onBrowse( wxCommandEvent& aEvent )
@@ -554,9 +746,61 @@ void DFArcFrame::refreshDmodList()
     {
       mNoDmods = true;
     }
+  refreshDmodLogos();
   RestoreListBoxFromConfig();
 }
 
+/**
+ * Create a big image with all the D-Mods logos, used for the
+ * transition effect that happens when selecting a different D-Mod.
+ */
+void DFArcFrame::refreshDmodLogos()
+{
+  mAllLogos = wxBitmap(LOGO_WIDTH, (mDModListBox->GetCount()+1) * LOGO_HEIGHT);
+  wxMemoryDC lAllDC(mAllLogos);
+  lAllDC.DrawBitmap(mDefaultLogoBitmap, 0,0, false);
+
+  for (unsigned int i = 0; i < mDModListBox->GetCount(); i++)
+    {
+      Integer *I = (Integer*)mDModListBox->GetClientObject(i);
+      int cur_dmod_index = I->i;
+      DMod cur_dmod = mAvailableDModsList.at(cur_dmod_index);
+
+      wxBitmap lLogoBitmap;
+      
+      wxString lDmodPreview(cur_dmod.GetFullPath() + _T("/preview.bmp"));
+      IOUtils::ciconvert(lDmodPreview);
+      wxString lDmodTitle(cur_dmod.GetFullPath() + _T("/graphics/title-01.bmp"));
+      IOUtils::ciconvert(lDmodTitle);
+      if (::wxFileExists(lDmodPreview) == true)
+	{
+	  lLogoBitmap = wxBitmap(lDmodPreview, wxBITMAP_TYPE_BMP);
+	}
+      else if (::wxFileExists(lDmodTitle) == true)
+	{
+	  wxImage lImage(lDmodTitle);
+	  lImage.Rescale(LOGO_WIDTH, LOGO_HEIGHT);
+	  lLogoBitmap = wxBitmap(lImage);
+	}
+      else
+	{
+	  lLogoBitmap = CreateTextLogo(cur_dmod.GetBaseName());
+	}
+      lLogoBitmap.SetWidth(LOGO_WIDTH);
+      lLogoBitmap.SetHeight(LOGO_HEIGHT);
+
+      lAllDC.DrawBitmap(lLogoBitmap, 0,(i+1)*LOGO_HEIGHT, false);
+      //mLogoButton->SetBitmap(lLogoBitmap);
+      //wxMemoryDC src(lLogoBitmap);
+      //wxBitmap dst_bitmap = mLogoButton->GetBitmap();
+      //wxMemoryDC dst(dst_bitmap);
+      //dst.Blit(0,0, LOGO_WIDTH, LOGO_HEIGHT, &src, 0,0);
+      //dst.DrawBitmap(lLogoBitmap, 0,0, false);
+      //dst.DrawRectangle(0,0, LOGO_WIDTH,LOGO_HEIGHT);
+      //mLogoButton->SetBitmap(dst_bitmap);
+    }
+}
+
 /**
  * Select DMod from configuration
  */
@@ -586,7 +830,7 @@ void DFArcFrame::RestoreListBoxFromConfig()
       mPlayButton->Disable();
       mEditButton->Disable();
       mPackageButton->Disable();
-      mLogoButton->SetBitmap(mDefaultLogoBitmap);
+      ((DFAnimationPanel*)mAnimationPanel)->setIndex(-1);
     }
 }
 
@@ -718,100 +962,3 @@ void DFArcFrame::populateAvailableDModsList()
   delete[] folders;
   return;
 }
-
-
-
-/**
- * Some packaged version of wxWidgets 2.6, such as 2.6.3.2 in Debian
- * Etch and Lenny, lack good enough ::wxLaunchDefaultBrowser
- * implementation, introduced in 2.6.4 (argh). In practice, it will
- * say it succeeded in launching the URL in the default browser, but
- * will probably just launch 'epiphany' which may not be installed. It
- * will still return true/success, denying simple work-arounds. wx2.8
- * is good. I eventually used conditional compilation to include
- * updated Unix code from wxWidgets 2.6.4.
- */
-bool DFArcFrame::launchURL(wxString url)
-{
-#if wxCHECK_VERSION(2, 6, 4) || !__UNIX__
-  return ::wxLaunchDefaultBrowser(url);
-#else
-/////////////////////////////////////////////////////////////////////////////
-// Name:        utilscmn.cpp
-// Purpose:     Miscellaneous utility functions and classes
-// Author:      Julian Smart
-// Modified by:
-// Created:     29/01/98
-// RCS-ID:      $Id: utilscmn.cpp,v 1.145.2.5 2007/03/20 12:39:53 VZ Exp $
-// Copyright:   (c) 1998 Julian Smart
-// Licence:     wxWindows licence
-/////////////////////////////////////////////////////////////////////////////
-
-    wxArrayString errors;
-    wxArrayString output;
-
-    // gconf will tell us the application to use as browser under GNOME
-    long res = wxExecute
-               (
-                wxT("gconftool-2 --get /desktop/gnome/applications/browser/exec"),
-                output,
-                errors,
-                wxEXEC_NODISABLE
-               );
-
-    if ( res != -1 && errors.empty() && !output.empty() )
-    {
-        wxString cmd = output[0];
-        cmd << _T(' ') << url;
-        if ( wxExecute(cmd) )
-            return true;
-    }
-    else // try the KDE way if gconf didn't work
-    {
-        // kfmclient directly opens the given URL
-        if ( wxExecute(wxT("kfmclient openURL ") + url) )
-            return true;
-    }
-
-    // if we got here, the platform-specific way of opening URLs failed, try
-    // the generic one
-#if wxUSE_MIMETYPE
-    // Non-windows way
-    bool ok = false;
-    wxString cmd;
-
-    wxFileType *ft = wxTheMimeTypesManager->GetFileTypeFromExtension(_T("html"));
-    if ( ft )
-    {
-        wxString mt;
-        ft->GetMimeType(&mt);
-
-        ok = ft->GetOpenCommand(&cmd, wxFileType::MessageParameters(url));
-        delete ft;
-    }
-
-    if ( !ok || cmd.empty() )
-    {
-        // fallback to checking for the BROWSER environment variable
-        cmd = wxGetenv(wxT("BROWSER"));
-        if ( !cmd.empty() )
-            cmd << _T(' ') << url;
-    }
-
-    ok = ( !cmd.empty() && wxExecute(cmd) );
-    if (ok)
-        return ok;
-
-    // no file type for HTML extension
-    wxLogError(_T("No default application configured for HTML files."));
-#endif // !wxUSE_MIMETYPE && !__WXMSW__
-
-    wxLogSysError(_T("Failed to open URL \"%s\" in default browser."),
-                  url.c_str());
-
-    return false;
-
-  //::wxMessageBox(wxString::Format(_("Visit %s !"), url.c_str()),
-  //		 _("Website (could not locate default browser)"));
-#endif
-}
